from setuptools import setup

setup(name='01_distributions',
      version='0.1',
      description='Gaussian distributions',
      packages=['01_distributions'],
      author = 'Piyush01',
      
      zip_safe=False)
